
# Copyright 2014 Intel Corporation, All Rights Reserved.

# Licensed under the Apache License, Version 2.0 (the"License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at

#  http://www.apache.org/licenses/LICENSE-2.0

# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied. See the License for the
# specific language governing permissions and limitations
# under the License.

from django.conf.urls import patterns, url
from .views import IndexView
from .views import CreateClusterView
from .views import IntegrateClusterView
from .views import ClusterAction
from .views import CheckClusterExist
from .views import update_table

urlpatterns = patterns('',
    url(r'^$', IndexView.as_view(), name='index'),
    url(r'^createclusterview/$', CreateClusterView.as_view(), name='createclusterview'),
    url(r'^integrateclusterview/$', IntegrateClusterView.as_view(), name='integrateclusterview'),
    url(r'^cluster/(?P<action>\w+)$', ClusterAction, name='clusteraction'),
    url(r'^check_cluster_exist/$', CheckClusterExist, name='check_cluster_exist'),
    url(r'^update_table/$', update_table, name='update_table'),
)
